@@ -1,5 +1,6 @@
 import logging
 import os
+import time
 from abc import ABC, abstractmethod
 from typing import NamedTuple, Dict, List
 
@@ -29,6 +30,7 @@ class CoreMetadata(NamedTuple):
     tags: List[str]
     model_version: str
     sdk_version: str
+    date_created: float
     pytorch_version: str
     citation: str
     is_experimental: bool
@@ -43,6 +45,7 @@ class NeutoneModel(ABC, nn.Module):
         super().__init__()
         self.MAX_N_PARAMS = constants.MAX_N_PARAMS
         self.SDK_VERSION = constants.SDK_VERSION
+        self.CURRENT_TIME = time.time()
         self.use_debug_mode = use_debug_mode
 
         assert len(self.get_neutone_parameters()) <= self.MAX_N_PARAMS
@@ -75,8 +78,12 @@ class NeutoneModel(ABC, nn.Module):
             ]
         ).unsqueeze(-1)
         self.register_buffer("default_param_values", default_param_values)
-        self.remapped_params = {neutone_param.name: default_param_values[idx]
-                                for idx, neutone_param in enumerate(self.get_neutone_parameters())}
+        self.remapped_params = {
+            neutone_param.name: default_param_values[idx]
+            for idx, neutone_param in enumerate(self.get_neutone_parameters())
+        }
+        # This is required for TorchScript typing when there are no Neutone parameters defined
+        self.remapped_params["__torchscript_typing"] = default_param_values[0]
 
     @abstractmethod
     def get_model_name(self) -> str:
@@ -209,36 +216,46 @@ class NeutoneModel(ABC, nn.Module):
     def get_neutone_parameters(self) -> List[NeutoneParameter]:
         return []
 
-    def get_default_param_values(self) -> Tensor:
-        return self.default_param_values
-
-    def get_wet_default_value(self) -> float:
-        return 1.0
-
-    def get_dry_default_value(self) -> float:
-        return 0.0
-
-    def get_input_gain_default_value(self) -> float:
-        """[0.0, 1.0] here maps to [-30.0db, +30.0db]"""
-        return 0.5
-
-    def get_output_gain_default_value(self) -> float:
-        """[0.0, 1.0] here maps to [-30.0db, +30.0db]"""
-        return 0.5
-
     def prepare_for_inference(self) -> None:
         """Prepare a model for inference and to be converted to torchscript."""
         self.use_debug_mode = False
         self.model.eval()
         self.eval()
 
+    @tr.jit.export
+    def get_default_param_values(self) -> Tensor:
+        return self.default_param_values
+
+    @tr.jit.export
+    def get_wet_default_value(self) -> float:
+        return 1.0
+
+    @tr.jit.export
+    def get_dry_default_value(self) -> float:
+        return 0.0
+
+    @tr.jit.export
+    def get_input_gain_default_value(self) -> float:
+        """[0.0, 1.0] here maps to [-30.0db, +30.0db]"""
+        return 0.5
+
+    @tr.jit.export
+    def get_output_gain_default_value(self) -> float:
+        """[0.0, 1.0] here maps to [-30.0db, +30.0db]"""
+        return 0.5
+
     @tr.jit.export
     def get_core_preserved_attributes(self) -> List[str]:
         return [
-            "to_core_metadata",
-            "model",
-            "default_param_values",
+            "model",  # nn.Module
+            "default_param_values",  # Registered buffer
+            "get_default_param_values",
+            "get_wet_default_value",
+            "get_dry_default_value",
+            "get_input_gain_default_value",
+            "get_output_gain_default_value",
             "get_core_preserved_attributes",
+            "to_core_metadata",
         ]
 
     @tr.jit.export
@@ -259,6 +276,7 @@ class NeutoneModel(ABC, nn.Module):
             model_version=self.get_model_version(),
             sdk_version=self.SDK_VERSION,
             pytorch_version=tr.__version__,
+            date_created=self.CURRENT_TIME,
             citation=self.get_citation(),
             is_experimental=self.is_experimental(),
         )
