@@ -3,7 +3,7 @@ import os
 from jsonschema import validate, ValidationError
 import requests
 
-from neutone_sdk.audio import mp3_b64_to_audio_sample
+from neutone_sdk.audio import AudioSample
 
 logging.basicConfig()
 log = logging.getLogger(__name__)
@@ -42,7 +42,7 @@ SCHEMA = {
         },
         "citation": {
             "type": "string",
-            "maxLength": 150,
+            "maxLength": 300,
         },
         "is_experimental": {
             "type": "boolean",
@@ -124,6 +124,8 @@ SCHEMA = {
             "minimum": 0,
         },
         "sdk_version": {"type": "string"},
+        "pytorch_version": {"type": "string"},
+        "date_created": {"type": "number"},
     },
     "definitions": {
         "neutoneParameter": {
@@ -162,6 +164,8 @@ SCHEMA = {
         "native_buffer_sizes",
         "look_behind_samples",
         "sdk_version",
+        "pytorch_version",
+        "date_created",
     ],
 }
 
@@ -184,8 +188,8 @@ def validate_metadata(metadata: dict) -> bool:
 
     # Check we can extract mp3s from the samples
     for audio_sample_pair in metadata["sample_sound_files"]:
-        mp3_b64_to_audio_sample(audio_sample_pair["in"])
-        mp3_b64_to_audio_sample(audio_sample_pair["out"])
+        AudioSample.from_b64(audio_sample_pair["in"])
+        AudioSample.from_b64(audio_sample_pair["out"])
 
     # We shouldn't have any problems here but as a sanity check
     for param_metadata in metadata["neutone_parameters"].values():
