@@ -17,15 +17,13 @@ class ChannelNormalizerSandwich(nn.Module):
     """
     Converts between mono and stereo channels as required without allocating memory.
     """
+
     def __init__(self, use_debug_mode: bool = True) -> None:
         super().__init__()
         self.use_debug_mode = use_debug_mode
         self.half_scalar = tr.tensor(0.5)
 
-    def forward(self,
-                x: Tensor,
-                should_be_mono: bool,
-                out_buffer: Tensor) -> Tensor:
+    def forward(self, x: Tensor, should_be_mono: bool, out_buffer: Tensor) -> Tensor:
         if self.use_debug_mode:
             assert x.ndim == 2
             assert x.size(0) <= 2
@@ -47,7 +45,9 @@ class ChannelNormalizerSandwich(nn.Module):
 
 
 class ResampleSandwich(ABC, nn.Module):
-    def __init__(self, in_sr: int, out_sr: int, in_bs: int, use_debug_mode: bool = True) -> None:
+    def __init__(
+        self, in_sr: int, out_sr: int, in_bs: int, use_debug_mode: bool = True
+    ) -> None:
         """
         Common interface for resampling sandwiches.
 
@@ -101,13 +101,16 @@ class PTResampler(ResampleSandwich):
     Antialiasing resampling using the default PyTorch audio resampling implementation.
     Slower, dynamically allocates memory, and is not TorchScript compatible.
     """
-    def __init__(self,
-                 in_sr: int,
-                 out_sr: int,
-                 in_bs: int,
-                 resampling_method: str = "sinc_interpolation",
-                 align_corners: bool = True,
-                 use_debug_mode: bool = True) -> None:
+
+    def __init__(
+        self,
+        in_sr: int,
+        out_sr: int,
+        in_bs: int,
+        resampling_method: str = "sinc_interpolation",
+        align_corners: bool = True,
+        use_debug_mode: bool = True,
+    ) -> None:
         self.resampling_method = resampling_method
         self.align_corners = align_corners
         self.in_resampler = None
@@ -119,12 +122,16 @@ class PTResampler(ResampleSandwich):
         self.out_sr = out_sr
         self.in_bs = in_bs
 
-        self.in_resampler = Resample(orig_freq=self.in_sr,
-                                     new_freq=self.out_sr,
-                                     resampling_method=self.resampling_method)
-        self.out_resampler = Resample(orig_freq=self.out_sr,
-                                      new_freq=self.in_sr,
-                                      resampling_method=self.resampling_method)
+        self.in_resampler = Resample(
+            orig_freq=self.in_sr,
+            new_freq=self.out_sr,
+            resampling_method=self.resampling_method,
+        )
+        self.out_resampler = Resample(
+            orig_freq=self.out_sr,
+            new_freq=self.in_sr,
+            resampling_method=self.resampling_method,
+        )
 
         tmp = self.in_resampler(tr.zeros((2, self.in_bs)))
         self.out_bs = tmp.size(1)
@@ -153,7 +160,7 @@ class PTResampler(ResampleSandwich):
             corner_2_value = x[:, -1]
             x = self.out_resampler(x)
             if x.size(1) > self.in_bs:
-                x = x[:, :self.in_bs]
+                x = x[:, : self.in_bs]
             if self.align_corners:
                 x[:, 0] = corner_1_value
                 x[:, -1] = corner_2_value
@@ -165,16 +172,14 @@ class InterpolationResampler(ResampleSandwich):
     Interpolation-based resampling using the default PyTorch linear interpolation implementation.
     Dynamically allocates memory.
     """
+
     def _process(self, x: Tensor, in_bs: int, out_bs: int) -> Tensor:
         if self.use_debug_mode:
             assert x.ndim == 2
             assert x.size(1) == in_bs
         if self.is_resampling():
             x = x.unsqueeze(0)
-            x = F.interpolate(x,
-                              out_bs,
-                              mode='linear',
-                              align_corners=True)
+            x = F.interpolate(x, out_bs, mode="linear", align_corners=True)
             x = x.squeeze(0)
         return x
 
@@ -190,13 +195,16 @@ class InplaceInterpolationResampler(ResampleSandwich):
     Interpolation-based resampling using a custom implementation.
     Does not dynamically allocate memory and is ~40% faster than the PyTorch implementation for common sampling rates.
     """
-    def __init__(self,
-                 in_n_ch: int,
-                 out_n_ch: int,
-                 in_sr: int,
-                 out_sr: int,
-                 in_bs: int,
-                 use_debug_mode: bool = True) -> None:
+
+    def __init__(
+        self,
+        in_n_ch: int,
+        out_n_ch: int,
+        in_sr: int,
+        out_sr: int,
+        in_bs: int,
+        use_debug_mode: bool = True,
+    ) -> None:
         self.in_n_ch = in_n_ch
         self.out_n_ch = out_n_ch
 
@@ -224,34 +232,52 @@ class InplaceInterpolationResampler(ResampleSandwich):
             assert self.out_bs >= 2
 
         scaling_factor_in = (self.in_bs - 1) / (self.out_bs - 1)
-        interp_in = tr.tensor([float(_) for _ in range(self.out_bs)]) * scaling_factor_in
+        interp_in = (
+            tr.tensor([float(_) for _ in range(self.out_bs)]) * scaling_factor_in
+        )
         floor_in = tr.floor(interp_in).to(tr.long)
-        self.floor_in = tr.clip(floor_in, 0, self.in_bs - 1)  # Prevents floating point errors
+        self.floor_in = tr.clip(
+            floor_in, 0, self.in_bs - 1
+        )  # Prevents floating point errors
         ceil_in = tr.ceil(interp_in).to(tr.long)
-        self.ceil_in = tr.clip(ceil_in, 0, self.in_bs - 1)  # Prevents floating point errors
-        self.interp_in = tr.clip(interp_in - self.floor_in, 0.0, 1.0)  # Prevents floating point errors
+        self.ceil_in = tr.clip(
+            ceil_in, 0, self.in_bs - 1
+        )  # Prevents floating point errors
+        self.interp_in = tr.clip(
+            interp_in - self.floor_in, 0.0, 1.0
+        )  # Prevents floating point errors
         self.in_a = tr.zeros((self.in_n_ch, self.out_bs))
         self.in_b = tr.zeros((self.in_n_ch, self.out_bs))
 
         scaling_factor_out = (self.out_bs - 1) / (self.in_bs - 1)
-        interp_out = tr.tensor([float(_) for _ in range(self.in_bs)]) * scaling_factor_out
+        interp_out = (
+            tr.tensor([float(_) for _ in range(self.in_bs)]) * scaling_factor_out
+        )
         floor_out = tr.floor(interp_out).to(tr.long)
-        self.floor_out = tr.clip(floor_out, 0, self.out_bs - 1)  # Prevents floating point errors
+        self.floor_out = tr.clip(
+            floor_out, 0, self.out_bs - 1
+        )  # Prevents floating point errors
         ceil_out = tr.ceil(interp_out).to(tr.long)
-        self.ceil_out = tr.clip(ceil_out, 0, self.out_bs - 1)  # Prevents floating point errors
-        self.interp_out = tr.clip(interp_out - self.floor_out, 0.0, 1.0)  # Prevents floating point errors
+        self.ceil_out = tr.clip(
+            ceil_out, 0, self.out_bs - 1
+        )  # Prevents floating point errors
+        self.interp_out = tr.clip(
+            interp_out - self.floor_out, 0.0, 1.0
+        )  # Prevents floating point errors
         self.out_a = tr.zeros((self.out_n_ch, self.in_bs))
         self.out_b = tr.zeros((self.out_n_ch, self.in_bs))
 
-    def _process(self,
-                 x: Tensor,
-                 n_ch: int,
-                 in_bs: int,
-                 interp_t: Tensor,
-                 floor_t: Tensor,
-                 ceil_t: Tensor,
-                 a_t: Tensor,
-                 b_t: Tensor) -> Tensor:
+    def _process(
+        self,
+        x: Tensor,
+        n_ch: int,
+        in_bs: int,
+        interp_t: Tensor,
+        floor_t: Tensor,
+        ceil_t: Tensor,
+        a_t: Tensor,
+        b_t: Tensor,
+    ) -> Tensor:
         if self.use_debug_mode:
             assert x.shape == (n_ch, in_bs)
         if not self.is_resampling():
@@ -264,21 +290,25 @@ class InplaceInterpolationResampler(ResampleSandwich):
         return a_t
 
     def process_in(self, x: Tensor) -> Tensor:
-        return self._process(x,
-                             self.in_n_ch,
-                             self.in_bs,
-                             self.interp_in,
-                             self.floor_in,
-                             self.ceil_in,
-                             self.in_a,
-                             self.in_b)
+        return self._process(
+            x,
+            self.in_n_ch,
+            self.in_bs,
+            self.interp_in,
+            self.floor_in,
+            self.ceil_in,
+            self.in_a,
+            self.in_b,
+        )
 
     def process_out(self, x: Tensor) -> Tensor:
-        return self._process(x,
-                             self.out_n_ch,
-                             self.out_bs,
-                             self.interp_out,
-                             self.floor_out,
-                             self.ceil_out,
-                             self.out_a,
-                             self.out_b)
+        return self._process(
+            x,
+            self.out_n_ch,
+            self.out_bs,
+            self.interp_out,
+            self.floor_out,
+            self.ceil_out,
+            self.out_a,
+            self.out_b,
+        )
